@@ -97,6 +97,18 @@ def get_should_use_product_plans(puppet_account_id, default_region=None):
     )
 
 
+@functools.lru_cache(maxsize=32)
+def get_should_use_shared_scheduler(puppet_account_id, default_region=None):
+    logger.info(
+        "getting should_use_shared_scheduler,  default_region: {}".format(
+            default_region
+        )
+    )
+    return get_config(puppet_account_id, default_region).get(
+        "should_use_shared_scheduler", False
+    )
+
+
 @functools.lru_cache(maxsize=32)
 def get_global_sharing_mode_default(puppet_account_id, default_region=None):
     logger.info(
