@@ -177,7 +177,7 @@ class ProvisionProductTask(ProvisioningTask, manifest_tasks.ManifestMixen):
                 product_id=self.product_id,
                 version=self.version,
                 version_id=self.version_id,
-                account_id=self.account_id,
+                account_id=self.account_id,  # TODO switch this to puppet_account_id but need to first ensure there is an association for the puppet user and then resolve CreateAssociationsInPythonForPortfolioTask differences
                 region=self.region,
             ),
         }
@@ -382,10 +382,19 @@ class ProvisionProductTask(ProvisioningTask, manifest_tasks.ManifestMixen):
                                 if output.get("OutputKey") == ssm_param_output.get(
                                     "stack_output"
                                 ):
+                                    ssm_parameter_name = ssm_param_output.get(
+                                        "param_name"
+                                    )
+                                    ssm_parameter_name = ssm_parameter_name.replace(
+                                        "${AWS::Region}", self.region
+                                    )
+                                    ssm_parameter_name = ssm_parameter_name.replace(
+                                        "${AWS::AccountId}", self.account_id
+                                    )
                                     found_match = True
                                     self.info(f"found value")
                                     ssm.put_parameter_and_wait(
-                                        Name=ssm_param_output.get("param_name"),
+                                        Name=ssm_parameter_name,
                                         Value=output.get("OutputValue"),
                                         Type=ssm_param_output.get(
                                             "param_type", "String"
